==> gulp-concat-0.0.36.tgz: gulp-concat/README.md <==
# Installation
> `npm install --save @types/gulp-concat`

# Summary
This package contains type definitions for gulp-concat (https://github.com/wearefractal/gulp-concat).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-concat.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-concat/index.d.ts)
````ts
/// <reference types="node" />

interface IOptions {
    newLine: string;
}

interface IFsStats {
    dev?: number | undefined;
    ino?: number | undefined;
    mode?: number | undefined;
    nlink?: number | undefined;
    uid?: number | undefined;
    gid?: number | undefined;
    rdev?: number | undefined;
    size?: number | undefined;
    blksize?: number | undefined;
    blocks?: number | undefined;
    atime?: Date | undefined;
    mtime?: Date | undefined;
    ctime?: Date | undefined;
}

interface IVinylOptions {
    cwd?: string | undefined;
    base?: string | undefined;
    path?: string | undefined;
    stat?: IFsStats | undefined;
    contents?: NodeJS.ReadableStream | Buffer | undefined;
}

interface IConcat {
    (filename: string, options?: IOptions): NodeJS.ReadWriteStream;
    (options: IVinylOptions): NodeJS.ReadWriteStream;
}

declare var _tmp: IConcat;
export = _tmp;

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 01:17:35 GMT
 * Dependencies: [@types/node](https://npmjs.com/package/@types/node)

# Credits
These definitions were written by [Keita Kagurazaka](https://github.com/k-kagurazaka).

==> gulp-concat-0.0.37.tgz: gulp-concat/README.md <==
# Installation
> `npm install --save @types/gulp-concat`

# Summary
This package contains type definitions for gulp-concat (https://github.com/wearefractal/gulp-concat).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-concat.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-concat/index.d.ts)
````ts
/// <reference types="node" />

interface IOptions {
    newLine: string;
}

interface IFsStats {
    dev?: number | undefined;
    ino?: number | undefined;
    mode?: number | undefined;
    nlink?: number | undefined;
    uid?: number | undefined;
    gid?: number | undefined;
    rdev?: number | undefined;
    size?: number | undefined;
    blksize?: number | undefined;
    blocks?: number | undefined;
    atime?: Date | undefined;
    mtime?: Date | undefined;
    ctime?: Date | undefined;
}

interface IVinylOptions {
    cwd?: string | undefined;
    base?: string | undefined;
    path?: string | undefined;
    stat?: IFsStats | undefined;
    contents?: NodeJS.ReadableStream | Buffer | undefined;
}

interface IConcat {
    (filename: string, options?: IOptions): NodeJS.ReadWriteStream;
    (options: IVinylOptions): NodeJS.ReadWriteStream;
}

declare var _tmp: IConcat;
export = _tmp;

````

### Additional Details
 * Last updated: Tue, 07 Nov 2023 03:09:37 GMT
 * Dependencies: [@types/node](https://npmjs.com/package/@types/node)

# Credits
These definitions were written by [Keita Kagurazaka](https://github.com/k-kagurazaka).
